@@ -1,43 +1,23 @@
 use crate::ctx;
-use crate::graphics::{resource, AsStd140, BufferBindingTarget, BufferBlockBindingTarget, BufferUsage};
+use crate::graphics::{
+    resource, std140::Std140Struct, BufferBindingTarget, BufferBlockBindingTarget, BufferUsage,
+};
 use core::marker::PhantomData;
-use crevice::std140::Std140;
 
 /// Stores a uniform on the device.
-pub struct Uniform<T: AsStd140> {
+pub struct Uniform<T: Std140Struct> {
     vbo: resource::Buffer,
     phantom: PhantomData<T>,
 }
 
-impl<T: AsStd140> Uniform<T> {
+impl<T: Std140Struct> Uniform<T> {
     /// Creates a new uniform.
     pub fn new<Z: Into<T>>(uniform: Z) -> Uniform<T> {
         let gl = ctx().graphics().gl();
 
         let vbo = gl.create_buffer();
         gl.bind_buffer(BufferBindingTarget::UniformBuffer, Some(vbo));
-        gl.buffer_data_u8_slice(
-            BufferBindingTarget::UniformBuffer,
-            uniform.into().as_std140().as_bytes(),
-            BufferUsage::StaticDraw,
-        );
-
-        Uniform {
-            vbo,
-            phantom: PhantomData,
-        }
-    }
-
-    pub(crate) fn new_internal() -> Uniform<T> {
-        let gl = ctx().graphics().gl();
-
-        let vbo = gl.create_buffer();
-        gl.bind_buffer(BufferBindingTarget::UniformBuffer, Some(vbo));
-        gl.buffer_data_empty(
-            BufferBindingTarget::UniformBuffer,
-            T::std140_size_static() as i32,
-            BufferUsage::StaticDraw,
-        );
+        gl.buffer_data(BufferBindingTarget::UniformBuffer, &[uniform.into()], BufferUsage::StaticDraw);
 
         Uniform {
             vbo,
@@ -49,11 +29,7 @@ impl<T: AsStd140> Uniform<T> {
     pub fn set<Z: Into<T>>(&mut self, uniform: Z) {
         let gl = ctx().graphics().gl();
         gl.bind_buffer(BufferBindingTarget::UniformBuffer, Some(self.vbo));
-        gl.buffer_data_u8_slice(
-            BufferBindingTarget::UniformBuffer,
-            uniform.into().as_std140().as_bytes(),
-            BufferUsage::StaticDraw,
-        );
+        gl.buffer_data(BufferBindingTarget::UniformBuffer, &[uniform.into()], BufferUsage::StaticDraw);
     }
 
     pub(crate) fn bind(&self, block: u32) {
@@ -62,7 +38,7 @@ impl<T: AsStd140> Uniform<T> {
     }
 }
 
-impl<T: AsStd140> Drop for Uniform<T> {
+impl<T: Std140Struct> Drop for Uniform<T> {
     fn drop(&mut self) {
         let gl = ctx().graphics().gl();
         gl.delete_buffer(self.vbo);
